#
# spec file for package heimer
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021 Fabio Pesari
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           heimer
Version:        4.4.0
Release:        1.4
Summary:        Mind map, diagram, and note-taking tool
License:        CC-BY-SA-3.0 AND GPL-3.0-only
Group:          Productivity/Office/Other
URL:            https://github.com/juzzlin/Heimer
Source0:        https://github.com/juzzlin/Heimer/archive/refs/tags/%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Xml)

%description
Heimer is a desktop application for creating mind maps and other
suitable diagrams. Features:
* Adjustable grid
* Automatic layout optimization
* Autosave
* Easy-to-use UI
* Export to PNG or SVG
* Forever 100% free
* Full undo/redo
* Nice animations
* Quickly add node text and edge labels
* Save/load in XML-based .ALZ-files
* Translations in English (default), Chinese, Dutch, Finnish, French, Italian, Spanish
* Very fast
* Zoom in/out/fit
* Zoom with mouse wheel

%prep
%setup -q -n Heimer-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install
%fdupes -s %{buildroot}%{_datadir}

%files
%doc README.md
%license COPYING
%{_bindir}/heimer
%{_datadir}/applications/heimer.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/256x256
%dir %{_datadir}/icons/hicolor/256x256/apps
%{_datadir}/icons/hicolor/256x256/apps/heimer.png
%{_datadir}/metainfo/heimer.appdata.xml
%{_datadir}/pixmaps/heimer.png

%changelog
* Wed Mar 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 4.4.0:
  New features:
  * Search text also in edge labels
  * Implement group deletion of edges
  * Apply text search on undo/redo
  Bug fixes:
  * Fix GitHub Issue #191: Windows: Text highlighted by the search
  not visible
  * Fix GitHub Issue #255: Run error in ArchLinux
  * Fix search field not always taking focus on startup
* Tue Dec 12 2023 Michael Vetter <mvetter@suse.com>
- Update to 4.3.0:
  * Fix #249: Option to include grid on export
    + Grid will be exported if set visible
    + Works for both PNG and SVG exports
  * Fix #251: Feature request: child has same colors as parent
    + Change "Copy on Drag" behavior so that only the style will be copied
    + Set default filename with a timestamp in PNG and SVG export dialogs
    + Disable recent file entries that don't exist anymore
  * Optimize rendering of grid lines
    + Prevent situations where a zoomed-out view would have way too
    many grid lines visible, even multiple lines per pixel
* Mon May 22 2023 Michael Vetter <mvetter@suse.com>
- Update to 4.2.0:
  New features:
  * Automatic zoom-to-fit on search
  * Enable clear button on search text edit
  Other:
  * Add small padding on the edge label text field
  * Don't zoom to fit on cleared search if used has unselected all nodes
  * Remove shadow effects from edges that are not completely visible while dragging
- Drop heimer-4.1.0-remove-range.patch
* Thu Mar 30 2023 Michael Vetter <mvetter@suse.com>
- Add heimer-4.1.0-remove-range.patch:
  Fix build for Tumbleweed with gcc13 by removing range dep
  See gh/juzzlin/Heimer#242
* Mon Mar 20 2023 Michael Vetter <mvetter@suse.com>
- Update to 4.1.0:
  New features:
  * Add setting for shadow effect optimization
  * Layout optimization
    + Allow bigger aspect ratio
    + Allow longer edges
  * Darker default outline for nodes
  * Add subtle outline for edge labels
  * Fix GitHub Issue #238: Shadow effects introduce performance issues
  * Fix GitHub Issue #239: Cannot drag if the drag position is
    inside the virtual rectangle spanned by an edge
  * Update Italian translations
  * Update Dutch translations
  Performance:
  * Don't update scene rect when adding edges
  * Remove shadow effects from edges as long edges can make dragging
    stutter
* Sat Mar 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 4.0.0:
  New features:
  * Add setting for 'inverted controls'
  * Add parameter initialization options to layout optimization dialog
  * Add progress indicator when opening a mind map
  * Add tool tips for optimizer parameters
  * Add tool tip text for selecting node group by intersection
  * Change help texts into tool tips
  Bug fixes:
  * Fix tab key not working properly with node and edge text inputs
  * Unselect implicitly selected node after context menu has closed
  * Don't autosave unmodified mind map on exit
  * Don't autosave unmodified mind map on new file or open file
  Other:
  * More subtle new version indicator with a timeout
  * Change help texts to tool tips in edit settings
  * Update Italian translations
  * Update Dutch translations
  * Breaking changes to ALZ-format (old files can still be opened normally)
    + Move style data into style element
    + Move layout optimizer config into metadata element
    + Save and load application and format versions separately
    + Rename index => i, index0 => i0, index1 => i1
* Tue Feb 14 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.7.0:
  New features:
  * Add default settings for arrow size and edge width
  * Add default settings for text size and font
  * Add edit option to mirror the layout horizontally or vertically
  * Animate edge deletion
  * Animate node deletion
  Bug fixes:
  * Fix node left selected on canceled node/text color dialog
* Wed Dec 21 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.6.4:
  * Fix crash when trying to copy a group of connected nodes
  * Update Italian translations
* Mon Dec 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.6.3:
  New features:
  * Fix Issue #229: Add option to automatically open the last
    used file on application start
  * Autoload can be now enabled in edit settings
  * Implement asynchronous file save for autosave
  * Fixes stuttering user experience on large files
  Bug fixes:
  * Didn't launch due to Wayland issues
  * Forced to X11 for now
  Other:
  * Initialize a new mind map to avoid an undefined state if the mind map
    fails to load
  * Apply autosave only when settings dialog is accepted
  * Increase edge with step to 0.25
  * Update Dutch and Italian translations
* Sun Nov 13 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.6.2:
  New features:
  * Add tooltips to node handles
  * Set handle background color based on node color
  * Light or dark text edit highlight based on node color
  Bug fixes:
  * Fix GitHub issue #224: Tests fail when compiled with UBSan
  * Fix GitHub Issue #226: Attached node background images not loading
  * Decode images in memory without exporting into a file first
  Other:
  * Add timestamp to log file name
  * Save immediately when autosave enabled
* Thu Sep 22 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.6.1:
  * Fix shadow effect of edge label when edge is selected
  * Fix edge label not deleted together with the edge
  * Fix edge context menu not opening when edge text edit right-clicked
  * constants.hpp: added to QVector so that the compiler wouldn't throw an error
* Mon Aug 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.6.0:
  * Usability improvements:
    + Show a dummy edge label with '...' when the actual label won't fit
    + Stack edge text edits on top of nodes
* Mon Aug  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.5.0:
  * Fix GitHub Issue #112: Optimizer: Take current node locations
    into account when building initial layout
    + This change makes the optimizer way more stable with respect
    to the original global placement
    + Tries to find the best possible initial locations for the
    nodes in a normalized coordinate space
    + Makes only local changes within a very small search radius
    (row-wise and cell-wise)
  * Update German and Dutch translations
* Tue Jun 28 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.4.0:
  * Fetch the newest version and show in status bar if newer
    version available
  * Fix GitHub Issue #210: Option to set shadow offset and disable shadows
    + Adds effects tab to the settings dialog
    + Shadow offset and blur radius can now be set
  * Fix GitHub Issue #211: Color defaults
    + Default colors can now be set via the default settings tab
  * Make it possible to tune shadow colors via the effects tab
* Tue May 24 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.3.0:
  * Add German translations
  * Fix #206: An option to change the size of the arrows
  * Toolbar now includes a spinner widget to set the arrow size
  * Fix #205: Click dragging from an existing node, then pressing
    delete before dropping the node, crashes the program
* Tue Mar 15 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.2.0:
  New features:
  * Fix GitHub Issue #181: Copy should copy also edges within
    the group. When copying (and pasting) nodes, also the edges
    within the copy group are now copied
  Bug fixes:
  * Fix GitHub Issue #195: Decrease size of "About" dialog
  Other:
  * Updated Dutch & Italian translations
* Tue Mar 15 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.1.0:
  New features:
  * Option to automatically snap existing nodes to grid
  * Option for dashed lines in the edge context menu
  Bug fixes:
  * Fix GitHub Issue #186: Icon is installed in
    /usr/share/icons/hicolor/64x64 but actual size is 256x256
  * Fix GitHub Issue #188: Double-clicking on a large node zooms
    in incorrectly
  * Fix GitHub Issue #189: Export to PNG breaks zoom out
  * Fix GitHub Issue #190: Export to PNG works only once
  Other:
  * Simplify edge context menu
* Tue Nov 30 2021 Fabio Pesari <fpesari@tuxfamily.org>
- First upload to openSUSE, version 3.0.0. Changes:
  * Double-click to zoom into a node
  * Make it possible to change the font
  * Make edge text disappear if it doesn't fit between nodes
  * Fix auto save not triggering immediately on file operations
